/* Usage:                  */
/* #include <stdio.h>      */
/* #include "wordfile.h"   */

typedef enum { notInWord, firstInWord, inWord } charkind;
typedef charkind (*wordfunction)(unsigned char, void*);

/* Function type used to identify words. The function must return 0  */
/* for characters not in a word, and non-zero for characters in a    */
/* word. The "void*" will be the same as the pointer passed to       */
/* wordfile_wordfunction for every call.                             */
/*                                                                   */
/* The first call immediately after a call returning 0, will be for  */
/* the same character as the previous time, to allow for separate    */
/* words with no space between them.                                 */

struct wordfile_struct;
typedef struct wordfile_struct WORDFILE;


WORDFILE* wordfile_open(const char* filename);

/* Open a word file                                             */
/*                                                              */
/* Return values: NULL, failure to open the file                */
/*                non-NULL, a value to use in wordfile_nextword */
/*                and wordfile_close.                           */
/*                                                              */
/*   filename != NULL                                           */
/*                                                              */
/* Postconditions:                                              */
/*  If success, the file is open.                               */


int wordfile_close(WORDFILE* wordfile);

/* Close the open wordfile                                      */
/*                                                              */
/* Return values: 0 failure to close the file.                  */
/*                1 succeeded in closing the file.              */
/*                                                              */
/* Postconditions:                                              */
/*   If success, the wordfile is closed.                        */


size_t wordfile_nextword(WORDFILE* wordfile,
			 char* buffer,
			 size_t buffersize);

/* Read the next word in the open word file into the buffer     */
/*                                                              */
/* Return values: The length of the word copied into the        */
/*                buffer. A value of "buffersize" indicates     */
/*                that the word has been truncated and that     */
/*                only the first buffersize-1 characters of     */
/*                the word are available.                       */
/*                                                              */
/* Preconditions:                                               */
/*   wordfile != NULL.                                          */
/*   buffersize >= 2                                            */
/*   buffer != NULL                                             */


void wordfile_wordfunction(WORDFILE* wordfile,
			   wordfunction function,
			   void* userdata);

/* Makes the wordfile use the function "function" when distinguishing */
/* words. "userdata" is passed to "function" in every call.           */
/*                                                                    */
/* Preconditions:                                                     */
/*   wordfile != NULL                                                 */
/*   No words are read from the word file                             */
/*   Current word definition is the default definition                */


void wordfile_wordchars(WORDFILE* wordfile, const char* string);

/* Makes the wordfile accept the characters in the string as          */
/* characters allowed in a word.                                      */
/*                                                                    */
/* Preconditions:                                                     */
/*   wordfile != NULL                                                 */
/*   No words are read from the word file                             */
/*   Current word definition is the default definition                */



